@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.3.4'
+VERSION = '0.3.5'
 
 import os
 import sys
@@ -317,7 +317,8 @@ class Kernel(object):
             stderr=stdout,
         )
         while make_process.poll() is None:
-            progress_bar(random.randint(1, 99), 100)
+            if self.verbose:
+                progress_bar(random.randint(1, 99), 100)
             time.sleep(1)
         if make_process.returncode != 0:
             print('Failed to make kernel')
@@ -328,6 +329,8 @@ class Kernel(object):
     def install(self):
         os.chdir('{0}/sources/linux-{1}'.format(self.root_dir, self.version))
         self.log('Installing the kernel image')
+        if not os.path.isdir('/boot'):
+            os.makedirs('/boot', 0o755, True)
         shutil.copy(
             'arch/x86/boot/bzImage',
             '/boot/vmlinuz-{0}_{1}'.format(self.version, self.revision)
